@@ -17,4 +17,10 @@ A simple app configuration scheme using YAML and class based defaults.
 ## Imports
 ##########################################################################
 
-from config import Configuration
+from .config import Configuration
+
+##########################################################################
+## Module Constants
+##########################################################################
+
+__version__ = "0.1.1"
